<?php

namespace Bydedi\Routing\DataCollector;

use Bydedi\DebugBar\DataCollector;
use Bydedi\DebugBar\DataCollectorInterface;
use Symfony\Component\Routing\RouterInterface;

class RouterDataCollector extends DataCollector implements DataCollectorInterface
{
    protected $router;

    public function __construct(RouterInterface $router)
    {
        $this->router = $router;
    }

    /**
     * Called by the DebugBar when data needs to be collected
     *
     * @return array Collected data
     */
    public function collect()
    {
        $data = array();

        $routes = $this->router->getRouteCollection()->all();
        foreach ($routes as $key => $route) {
            $dataForRoute = array();
            $dataForRoute['path'] = $route->getPath();
            $defaults = $route->getDefaults();
            $dataForRoute['controller'] = $defaults['_controller'];
            $dataForRoute['action'] = $defaults['_action'];

            $methods = $route->getMethods();
            if (!empty($methods)) {
                $dataForRoute['methods'] = $methods;
            }

            $data[$key] = $dataForRoute;
        }

        foreach ($data as $k => $v) {
            if (!is_string($v)) {
                $v = $this->getDataFormatter()->formatVar($v);
            }
            $data[$k] = $v;
        }

        return $data;
    }

    /**
     * Returns the unique name of the collector
     *
     * @return string
     */
    public function getName()
    {
        return 'Routes';
    }

    /**
     * Returns a hash where keys are control names and their values
     * an array of options as defined in {@see DebugBar\JavascriptRenderer::addControl()}
     *
     * @return array
     */
    public function getWidgets()
    {
        $name = $this->getName();
        return array(
            "$name" => array(
                "icon" => "gear",
                "widget" => "PhpDebugBar.Widgets.VariableListWidget",
                "map" => "$name",
                "default" => "{}"
            )
        );
    }
}
