<?php

namespace Bydedi\Security\Event;

use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class SecurityEvent
 * @package Bydedi\Security\Event
 */
class SecurityEvent extends Event
{
    /**
     * @var array
     */
    protected $roles;

    /**
     * @var Request
     */
    protected $request;

    /**
     * The response object.
     *
     * @var Response
     */
    protected $response;

    /**
     * @param array $roles
     * @param Request $request
     */
    public function __construct($roles, Request $request)
    {
        $this->roles = $roles;
        $this->request = $request;
    }

    /**
     * @return array
     */
    public function getRoles()
    {
        return $this->roles;
    }

    /**
     * @return Request
     */
    public function getRequest()
    {
        return $this->request;
    }

    /**
     * Returns the response object.
     *
     * @return Response
     *
     * @api
     */
    public function getResponse()
    {
        return $this->response;
    }

    /**
     * Sets a response and stops event propagation.
     *
     * @param Response $response
     *
     * @api
     */
    public function setResponse(Response $response)
    {
        $this->response = $response;

        $this->stopPropagation();
    }

    /**
     * Returns whether a response was set.
     *
     * @return bool Whether a response was set
     *
     * @api
     */
    public function hasResponse()
    {
        return null !== $this->response;
    }
}
